﻿// See https://aka.ms/new-console-template for more information

using System.Runtime.InteropServices;

// 常量定义
const int GWL_STYLE = -16;
const int WS_BORDER = 0x00800000;  // 边框
const int WS_CAPTION = 0x00C00000; // 标题栏
const int WS_THICKFRAME = 0x00040000; // 可调整大小的框
const int SW_SHOWNORMAL = 1;


if (args.Length < 5)
{
    Console.WriteLine("用法: WndTricker <窗口标题> <x坐标> <y坐标> <宽度> <高度> [重试次数] [重试间隔毫秒]");
    return -1;
}

// 从命令行参数获取窗口标题、x、y、宽度和高度
string windowTitle = args[0];
if (!int.TryParse(args[1], out int x) ||
    !int.TryParse(args[2], out int y) ||
    !int.TryParse(args[3], out int width) ||
    !int.TryParse(args[4], out int height))
{
    Console.WriteLine("参数无效，请确保 x, y, 宽度和高度是整数");
    return -2;
}

// 解析可选参数：重试次数和重试间隔
int retries = 0; // 默认不重试
int retryInterval = 1000; // 默认重试间隔 1000 毫秒
if (args.Length >= 6 && !int.TryParse(args[5], out retries))
{
    Console.WriteLine("重试次数无效，请确保是整数");
    return -3;
}
if (args.Length >= 7 && !int.TryParse(args[6], out retryInterval))
{
    Console.WriteLine("重试间隔无效，请确保是整数");
    return -4;
}

IntPtr hWnd = IntPtr.Zero;
int attempts = 0;

// 如果需要重试，尝试查找窗口
while (hWnd == IntPtr.Zero && attempts <= retries)
{
    hWnd = FindWindow(null, windowTitle);
    if (hWnd == IntPtr.Zero && attempts < retries)
    {
        attempts++;
        Console.WriteLine($"标题为 {windowTitle} 的窗口未找到，间隔 {retryInterval} 毫秒后，尝试第 {attempts} 次重试...");
        Thread.Sleep(retryInterval);
    }
}

if (hWnd == IntPtr.Zero)
{
    Console.WriteLine($"标题为 {windowTitle} 的窗口未找到，退出程序");
    return -10;
}

// 去掉窗口的边框
var currentStyle = GetWindowLong(hWnd, GWL_STYLE);
SetWindowLong(hWnd, GWL_STYLE, currentStyle & ~(WS_BORDER | WS_CAPTION | WS_THICKFRAME));

// 移动窗口到指定位置并设置大小
SetWindowPos(hWnd, IntPtr.Zero, x, y, width, height, 0);

// 显示窗口
ShowWindow(hWnd, SW_SHOWNORMAL);

Console.WriteLine($"标题为 {windowTitle} 的窗口已去掉边框并移动到 ({x}, {y})，大小已设置为 {width}x{height}");


return 0;


// Windows API 函数声明
[DllImport("user32.dll", CharSet = CharSet.Auto)]
static extern IntPtr FindWindow(string? lpClassName, string lpWindowName);

[DllImport("user32.dll")]
static extern int SetWindowLong(IntPtr hWnd, int nIndex, int dwNewLong);

[DllImport("user32.dll")]
static extern bool SetWindowPos(IntPtr hWnd, IntPtr hWndInsertAfter, int x, int y, int width, int height, uint uFlags);

[DllImport("user32.dll")]
static extern bool ShowWindow(IntPtr hWnd, int nCmdShow);



// 获取窗口样式
[DllImport("user32.dll")]
static extern int GetWindowLong(IntPtr hWnd, int nIndex);